# frozen_string_literal: true

module Adsf
  module Rack
  end
end

require 'adsf/rack/index_file_finder'
require 'adsf/rack/caching'
require 'adsf/rack/cors'
require 'adsf/rack/auto_file_extensions'
